@@ -16,7 +16,7 @@ stat_jsfs_class <- R6Class("stat_jsfs", inherit = sumstat_class,
       super$initialize(name, transformation)
     },
     calculate = function(seg_sites, trees, files, model) {
-      ind_per_pop <- lapply(private$populations, get_population_indiviuals,
+      ind_per_pop <- lapply(private$populations, get_population_individuals,
                             model = model)
 
       if (private$per_locus) {
@@ -31,21 +31,27 @@ stat_jsfs_class <- R6Class("stat_jsfs", inherit = sumstat_class,
   )
 )
 
-#' Calculates the Joint Site Frequency Spectrum from simulations
+#' Summary Statistic: Joint Site Frequency Spectrum
+#'
+#' The summary statistic calculates the joint site frequency
+#' spectrum (JSFS) for multiple populations.
 #'
 #' @inheritParams sumstat_four_gamete
-#' @param populations The populations for which the statistic is calculated.
-#' @param per_locus If \code{TRUE}, the JSFS is return for each locus instead
+#' @param populations An integer vector containing the populations for which
+#'        the JSFS is generated.
+#' @param per_locus If \code{TRUE}, the JSFS is returned for each locus instead
 #'   of globally. In this case, the result is a list, where each entry is the
 #'   JSFS for the corresponding locus.
+#' @return The JSFS, given as an array. The dimensions correspond to the
+#'   populatons as given in the \code{populations} argument.
+#' @template summary_statistics
 #' @export
 #' @examples
-#' set.seed(75)
-#' model <- coal_model(2:4, 2) +
+#' model <- coal_model(c(2, 3, 4), 2) +
 #'   feat_mutation(5) +
 #'   feat_migration(1, symmetric = TRUE) +
 #'   sumstat_jsfs("jsfs_12", populations = c(1, 2)) +
-#'   sumstat_jsfs("jsfs_123", populations = 1:3)
+#'   sumstat_jsfs("jsfs_123", populations = c(1, 2, 3))
 #' stats <- simulate(model)
 #' print(stats$jsfs_12)
 #' print(stats$jsfs_123)
