@@ -5,7 +5,6 @@ test_that("Creation of sample features works", {
   expect_equal(feat_sample(1:5)$get_sizes(), 1:5)
   expect_error(feat_sample("blub"))
   expect_error(feat_sample(numeric(0)))
-  expect_error(feat_sample(2, 5))
 })
 
 
@@ -15,6 +14,13 @@ test_that("sample sizes are reported corrently", {
 })
 
 
+test_that("sample sizes are reported corrently in polyploid models", {
+  expect_equal(get_sample_size(coal_model(c(10, 15), ploidy = 2)), c(20, 30))
+  expect_equal(get_sample_size(coal_model(c(10, 15), ploidy = 3)), c(30, 45))
+  expect_equal(get_sample_size(coal_model(3, ploidy = 8)), 24)
+})
+
+
 test_that("generating scrm cmd works", {
   model <- coal_model(15, 1)
   expect_equal(get_simulator("scrm")$get_cmd(model), "scrm 15 1 ")
