@@ -7,8 +7,10 @@ test_that("calculation of the JSFS is correct", {
                                                    1, 0, 0, 1,
                                                    1, 1, 1, 1,
                                                    1, 0, 1, 0,
-                                                   1, 0, 1 ,0 ),
-                                                 nrow=7, ncol=4, byrow = TRUE),
+                                                   1, 0, 1, 0),
+                                                 nrow = 7,
+                                                 ncol = 4,
+                                                 byrow = TRUE),
                                           c(0.1, 0.2, 0.5, 0.7)))
   jsfs_3_pop <- calc_jsfs(seg_sites_3_pop, list(1:2, 3:4, 5:7))
   expect_is(jsfs_3_pop, "array")
@@ -16,7 +18,7 @@ test_that("calculation of the JSFS is correct", {
                                         0, 1, 0, 0, 0, 0, 0, 1, 0,
                                         0, 0, 0, 0, 0, 0, 0, 0, 0,
                                         0, 1, 0, 0, 0, 1, 0, 0, 0),
-                                      dim=c(2, 2, 3) + 1))
+                                      dim = c(2, 2, 3) + 1))
 
 
   seg_sites_3_pop <- list(create_segsites(matrix(c(1, 0, 1, 0,
@@ -25,13 +27,15 @@ test_that("calculation of the JSFS is correct", {
                                                    0, 0, 0, 1,
                                                    1, 1, 1, 1,
                                                    1, 0, 1, 0,
-                                                   1, 0, 1 ,0 ),
-                                                 nrow=7, ncol=4, byrow = TRUE),
+                                                   1, 0, 1, 0),
+                                                 nrow = 7,
+                                                 ncol = 4,
+                                                 byrow = TRUE),
                                           c(0.1, 0.2, 0.5, 0.7)))
   jsfs_3_pop <- calc_jsfs(seg_sites_3_pop, list(1, 2:6, 7))
   expect_equivalent(jsfs_3_pop, array(c(0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0,
                                         0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0),
-                                      dim=c(1, 5, 1) + 1))
+                                      dim = c(1, 5, 1) + 1))
 
   seg_sites <- list(create_segsites(matrix(c(1, 0, 1, 0,
                                              1, 1, 0, 1,
@@ -52,13 +56,13 @@ test_that("calculation of the JSFS is correct", {
   jsfs2 <- calc_jsfs(seg_sites, list(2:4, 1))
   expect_equivalent(jsfs2, t(jsfs))
 
-  jsfs <- calc_jsfs(seg_sites, list(c(1,3), c(2,4)))
+  jsfs <- calc_jsfs(seg_sites, list(c(1, 3), c(2, 4)))
   expect_equivalent(jsfs, matrix(c(0, 1, 0,
                                    1, 0, 2,
                                    0, 0, 0), 3, 3, byrow = TRUE)) #nolint
 
-  expect_error(calc_jsfs(seg_sites, c(1,3), c(2,5)))
-  expect_error(calc_jsfs(seg_sites, c(1,7), c(2,3)))
+  expect_error(calc_jsfs(seg_sites, c(1, 3), c(2, 5)))
+  expect_error(calc_jsfs(seg_sites, c(1, 7), c(2, 3)))
   calc_jsfs(seg_sites, list(numeric(), 1:4))
 
 
